==> nautilus-0.1.0.tar.gz: nautilus-0.1.0/libnautilus-extensions/nautilus-view-identifier.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-

   nautilus-view-identifier.h: Unique ID/Human-readable name pairs for views
 
   Copyright (C) 2000 Eazel, Inc.
  
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
  
   You should have received a copy of the GNU General Public
   License along with this program; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
  
   Author: Maciej Stachowiak <mjs@eazel.com>
*/

#ifndef NAUTILUS_VIEW_IDENTIFIER_H
#define NAUTILUS_VIEW_IDENTIFIER_H

/* FIXME bugzilla.eazel.com 1291: 
 * Without this define liboaf doesn't include popt.h, causing trouble
 * later; this mechanism should be fixed. 
 */
#define HAVE_POPT_H
#include <liboaf/liboaf.h>

typedef struct {
	char *iid;	/* Unique ID */
	char *name;	/* human-readable name */
} NautilusViewIdentifier;

NautilusViewIdentifier *nautilus_view_identifier_new                      (const char             *iid, 
									   const char             *name);
NautilusViewIdentifier *nautilus_view_identifier_new_from_oaf_server_info (OAF_ServerInfo         *server, 
									   char                   *name_attribute);
NautilusViewIdentifier *nautilus_view_identifier_new_from_content_view    (OAF_ServerInfo         *server);
NautilusViewIdentifier *nautilus_view_identifier_new_from_sidebar_panel   (OAF_ServerInfo         *server);
NautilusViewIdentifier *nautilus_view_identifier_copy			  (NautilusViewIdentifier *identifier);

void                    nautilus_view_identifier_free                     (NautilusViewIdentifier *identifier);
void                    nautilus_view_identifier_list_free                (GList                  *identifiers);
int                     nautilus_view_identifier_compare                  (NautilusViewIdentifier *a, 
									   NautilusViewIdentifier *b);

#endif

==> nautilus-0.5.tar.gz: nautilus-0.5/libnautilus-extensions/nautilus-view-identifier.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-

   nautilus-view-identifier.h: Unique ID/Human-readable name pairs for views
 
   Copyright (C) 2000 Eazel, Inc.
  
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
  
   You should have received a copy of the GNU General Public
   License along with this program; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
  
   Author: Maciej Stachowiak <mjs@eazel.com>
*/

#ifndef NAUTILUS_VIEW_IDENTIFIER_H
#define NAUTILUS_VIEW_IDENTIFIER_H

/* FIXME bugzilla.eazel.com 1291: 
 * Without this define liboaf doesn't include popt.h, causing trouble
 * later; this mechanism should be fixed. 
 */
#define HAVE_POPT_H
#include <liboaf/liboaf.h>

typedef struct {
	char *iid;	/* Unique ID */
	char *name;	/* human-readable name */
} NautilusViewIdentifier;

NautilusViewIdentifier *nautilus_view_identifier_new                      (const char             *iid,
									   const char             *name);
NautilusViewIdentifier *nautilus_view_identifier_new_from_oaf_server_info (OAF_ServerInfo         *server,
									   char                   *name_attribute);
NautilusViewIdentifier *nautilus_view_identifier_new_from_content_view    (OAF_ServerInfo         *server);
NautilusViewIdentifier *nautilus_view_identifier_new_from_sidebar_panel   (OAF_ServerInfo         *server);
NautilusViewIdentifier *nautilus_view_identifier_copy                     (NautilusViewIdentifier *identifier);
void                    nautilus_view_identifier_free                     (NautilusViewIdentifier *identifier);
int                     nautilus_view_identifier_compare                  (NautilusViewIdentifier *a,
									   NautilusViewIdentifier *b);
/* lists of NautilusViewIdentifier */
GList *                 nautilus_view_identifier_list_copy                (GList                  *list);
void                    nautilus_view_identifier_list_free                (GList                  *list);

#endif /* NAUTILUS_VIEW_IDENTIFIER */
